////////////////////////////////////////////////////////////////////////
// Class:       SupernovaTrigger
// Module Type: filter
// File:        SupernovaTrigger_module.cc
//
// Generated at Mon Dec 17 15:29:53 2012 by Zukai Wang using artmod
// from art v1_02_06.
////////////////////////////////////////////////////////////////////////

#include "art/Framework/Core/EDFilter.h"
#include "art/Framework/Core/ModuleMacros.h"
#include "art/Persistency/Common/Assns.h"
#include "art/Framework/Principal/Handle.h"	
#include "art/Framework/Principal/Event.h"
//#include "art/Framework/Services/Optional/TFileService.h" 

#include "DDTBaseDataProducts/BaseProducts.h"
#include "DDTBaseDataProducts/Boundary.h"
#include "DDTBaseDataProducts/BoundaryList.h"
#include "DDTBaseDataProducts/HitList.h"
#include "DDTBaseDataProducts/DAQHit.h"
#include "DDTBaseDataProducts/GroupedHitList.h"
#include "DDTBaseDataProducts/TriggerDecision.h"	
#include "DDTBaseDataProducts/EventHeader.h"	
#include "DDTUtilities/AssociationUtil.h"

#include "DAQMessages/ccpp_NSNMessages.h"
#include "DAQMessages/DDSMailbox.hpp"

#include "SuperNovaDDT/clusterInfo.h"
#include "SuperNovaDDT/MessageBuffer.h"

#include <string>
#include <queue>
#include <algorithm>
#include <functional>

namespace novaddt {
  class SupernovaTrigger;
  class SliceSelector;
};

class novaddt::SliceSelector{
/// a class to check if the slice passes given cut
  public:
    SliceSelector(fhicl::ParameterSet const & p):
        adc_min (p.get<unsigned>("adc_min")),
        adc_max (p.get<unsigned>("adc_max")),
        n_min (p.get<unsigned>("n_min")),
        n_max (p.get<unsigned>("n_max"))
        {}
        
    bool checkSlice(const novaddt::HitList& slice){
       clusterInfo c=CalcCluster(slice); 
       //check if adc value for slice is whithin limits
       return (c.adc>=adc_min && c.adc<=adc_max) &&
               (c.nx>=n_min && c.nx<=n_max) &&
               (c.ny>=n_min && c.ny<=n_max);
    }
  private:
    unsigned adc_min,adc_max;
    unsigned n_min, n_max;  
};

class novaddt::SupernovaTrigger : public art::EDFilter {
public:
  explicit SupernovaTrigger(fhicl::ParameterSet const & p);
  virtual ~SupernovaTrigger();
  virtual bool filter(art::Event & e) override;
  virtual void endJob() override;

  uint64_t GetHits(const art::Event & e);
  uint64_t GetTime(const art::Event & e);
private:
  SliceSelector _selector;
  std::string _header_label;
  std::string _slice_label;
  std::string _slice_instance;
  DDSOutbox<nsnmessages::NSNPackedMessage> _mailbox;
  MessageBuffer _messageBuffer;
};

novaddt::SupernovaTrigger::SupernovaTrigger(fhicl::ParameterSet const & p):
  _selector(p.get<fhicl::ParameterSet>("slice_selection")),
  _header_label   (p.get< std::string >("header_label"  )), 
  _slice_label    (p.get< std::string >("slice_label"     )),
  _slice_instance (p.get< std::string >("slice_instance"  )),
  _mailbox("SuperNovaDDT",
           p.get<unsigned>("dds_partition"),
           p.get<std::string>("dds_mailbox")),
  _messageBuffer("SuperNovaSHMEM","messageBuffer",10)

{   
    // std::cout<<"read shared buffer of size "<<_messageBuffer.size()<<std::endl;
     
  // Call appropriate Produces<>() functions here.
  // produces<std::vector<TriggerDecision>>("TriggerDecisions");
//  art::ServiceHandle<art::TFileService> tfs;
//  _Hist_ADC=tfs->make<TH1D>("hADC","Slices ADC; ADC",100,0,20000);
}

novaddt::SupernovaTrigger::~SupernovaTrigger()
{
  // Clean up dynamic memory and other resources here.
}

uint64_t novaddt::SupernovaTrigger::GetHits(const art::Event & e)
{
  art::Handle<std::vector<novaddt::HitList> > slices;
  e.getByLabel(_slice_label, _slice_instance, slices);
  //calculate hits in signal region
  uint64_t hits=0;
    for (auto const& slice : *slices)
     if(_selector.checkSlice(slice))hits++;
  return hits;
}

uint64_t novaddt::SupernovaTrigger::GetTime(const art::Event & e){
    const uint64_t msec=64000; //TDC ticks/msec
    art::Handle<novaddt::EventHeader> header;
    if(e.getByLabel("hitProducer",_header_label,header))
        return header->timeStart/msec;
    return e.event()*5;
}

bool novaddt::SupernovaTrigger::filter(art::Event & e)
{
    novaddt::MessageBuffer::Point p(GetTime(e),GetHits(e));
    _messageBuffer.addPoint(p);
    std::cout<<"buffer["<<_messageBuffer.size()<<"]: "<<p.first<<" "<<p.second<<std::endl;
    if(_messageBuffer.isFull()){
        auto message=_messageBuffer.makeMessageAndClear();
       _mailbox<<message;
       std::cout<<"message sent!"<<std::endl;
    }
  return false;
}


void novaddt::SupernovaTrigger::endJob()
{
}
DEFINE_ART_MODULE(novaddt::SupernovaTrigger)
