#!/bin/sh  
#
#  NOvA-ART setup script
#  B. Rebel - June 19, 2008
#  G. Davies - April 10, 2011
#  stolen from P. Shanahan script for nova
#  G.Davies - March 15, 2012
#  Major change to mirror how Online sets up UPS products

#  Based on logic of SRT setup scripts
#
#  This script does nothing other than setup another (temporary) script, which 
#  will either be in csh or sh, as desired, and then return the full name
#  of the temporary script.  
#  
#  It is intended that a wrapper will then source the temp script.
#  
#  Why is it done this way?  Basically to allow one script to handle 
#  csh and sh.  The persistence of variables requires source'ing rather
#  than direct execution, but sourcing is incompatible with forcing a
#  shell.  So, we force the shell, but then write a sourceable file
#  in the user's prefered shell.


#################################################################
########### Following routines are site-specific   ##############
#################################################################
remove_tww () {
    #  remove TheWrittenWord from the path. Evil. Bad.    
    print_var PATH "\`dropit -p \$PATH /opt/TWWfsw/bin\`"  $shell_type
}

set_defaults () {
    shell_type=csh
    release=default
    testrel=.
    build=debug
    nova_lnk=pro
    find_output_file_name
}

set_ups () {
    
    if [ -z "${EXTERNALS}" ]; then
	echo "You need to set the EXTERNALS directory"
    else
	upssource="${EXTERNALS}/setup"
    fi
    if [ -f $upssource ]; then
	insert_source $upssource
    fi
}

usage () {
    echo "" >&2
    echo "usage: `basename $0` [options]" >&2
    echo "options:" >&2
    echo "     -h, --help: prints this usage message" >&2
    echo "     -r, --release: specifies the release to be set up" >&2
    echo "     -b, --build: specifies the build-type (debug or prof)" >&2
    exit
}

process_args () {
    while getopts "hncsr:b:-:" opt; do 
	if [ "$opt" = "-" ]; then
	    opt=$OPTARG
	fi
	case $opt in
	    h | help)
		usage
		;;
	    s | sh)
		shell_type=sh
		;;
	    c | csh)
		shell_type=csh
		;;
	    r | release)
		release=$OPTARG
		nova_lnk=$release
		;;
	    b | build)
		build=$OPTARG
		;;
	    *) usage
		;;
	    
	esac
    done
}

find_output_file_name () {
    output_file="/tmp/env_tmp.$$"
    if [ -f $output_file ]; then
	i=0
	while [ -f $output_file ]; do
	    i=`expr $i + 1`
	    output_file="/tmp/env_tmp.$i.$$"
	done
	fi
}

get_vars () {
	process_args $*
}

print_var () {
    # print a statement to set a variable in the desired shell type
    local_style=$3
    if [ "$local_style" = "sh" ]; then
	echo "$1=\"$2\"" >> $output_file
	echo "export $1" >> $output_file
    elif [ "$local_style" = "csh" ]; then
	echo "setenv $1 \"$2\"" >> $output_file
    elif [ "$local_style" = "human" ]; then
	echo "$1 = \"$2\""
    fi
}

unprint_var () {
    # print a statement to set a variable in the desired shell type
    local_style=$2
    if [ "$local_style" = "sh" ]; then
	echo "unset $1" >> $output_file
    elif [ "$local_style" = "csh" ]; then
	    echo "unsetenv $1" >> $output_file
    elif [ "$local_style" = "human" ]; then
	echo "unsetting $1"
    fi
}

insert_source () {
    echo "source $1" >> $output_file
}

insert_cmd () {
    echo "$1" >> $output_file
}

set_extern () {
    # a file containing the ups setup command args for each external
    # product
    if [[ "$build" = "prof" || "$build" = "maxopt" ]];then
	srt_ups_versions='$SRT_PUBLIC_CONTEXT/setup/novaddt-ups-externals-$SRT_BASE_RELEASE-maxopt'
    else
	srt_ups_versions='$SRT_PUBLIC_CONTEXT/setup/novaddt-ups-externals-$SRT_BASE_RELEASE'
    fi
    
    # the script to run the setups
    srt_ups_script='$SRT_DIST/setup/setup_srt_ups.'$shell_type

    insert_source "$srt_ups_script $srt_ups_versions"
}

set_srt () {

    # may need this(?) (see SoftRelTools/HEAD/include/arch_spec_f77.mk)
    # setenv SRT_USE_F2C true

    # Source the srt setup file
    insert_source "\$SRT_DIST/srt/srt.$shell_type"

    # setup desired release for the user. This adds the lib and bin areas
    # for the chosen base release to $path and to LD_LIBRARY_PATH
    #
    # first try to unsetup the current settings

    if [ $release = "none" ]; then
      	echo "Skipping SRT Setup"
    else
       	srt_setup_cmd="srt_setup -d"
       	if [ $release = "default" ]; then
	    srt_setup_cmd="$srt_setup_cmd SRT_QUAL=$build"

	else
	    srt_setup_cmd="$srt_setup_cmd SRT_QUAL=$build SRT_BASE_RELEASE=$release"
       	fi
	insert_cmd "srt_setup --unsetup"
	insert_cmd "$srt_setup_cmd"
    fi
    
    #set environmental variables necessary for using ART FileInPath functionality
    print_var FW_BASE         "\${SRT_PUBLIC_CONTEXT}"                                 $shell_type
    print_var FW_RELEASE_BASE "\${SRT_PUBLIC_CONTEXT}"                                 $shell_type
    print_var FW_DATA         "/nova/data"   $shell_type 
    # this one is fermilab site-specific, need to remove somehow
    # possibly put in setup function in bash
    print_var FW_SEARCH_PATH  "\${SRT_PUBLIC_CONTEXT}/:\${FW_DATA}" 		       $shell_type
    print_var FHICL_FILE_PATH "./:\${SRT_PUBLIC_CONTEXT}/job/:\${SRT_PUBLIC_CONTEXT}/" $shell_type

}

set_devdb () {
  
    print_var NOVADBHOST      "novadbdev.fnal.gov"                                     $shell_type
    print_var NOVADBNAME      "nova_dev"   					       $shell_type
    print_var NOVADBUSER      "nova_reader"                                            $shell_type
    print_var NOVADBPWDFILE   "/nova/app/db/nova_reader_pwd"                           $shell_type
    print_var NOVADBPORT      "5432"                                                   $shell_type

}

set_paths () {
    
    print_var LD_LIBRARY_PATH "\${LD_LIBRARY_PATH}"              $shell_type
    print_var LD_LIBRARY_PATH "\${LD_LIBRARY_PATH}"              $shell_type
 
}

finish () {
	echo $output_file
}

main () {

     set_defaults
     get_vars $*
     set_srt
     set_ups
     set_extern
     set_devdb
     set_paths
     finish
}

main $*